/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.v2v;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.platform.raspberry.generator.extension.library.PiHALLibraryGeneratorExtensionBase;

/**
 * Base class for all executables of the v2v communicaton .
 * 
 * @author duenhuber
 */
abstract class V2VGeneratorExtensionBase<T extends EObject> extends
		PiHALLibraryGeneratorExtensionBase<T> {
	/** Constructor. */
	public V2VGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonVariableDeclarationCode() {
		// no declartion needed yet
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonAuxiliaryFunctions() {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getSingletonInitializationCode() {
		// build string
		StringBuilder sb = new StringBuilder();
		sb.append("// initialize the v2v communicaton\n");
		// initialize the v2v communicaton
		sb.append("af3_v2v_activate( 9990,  -1, true);\n");
		return sb.toString();

	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonTerminationCode() {
		return "af3_v2v_deactivate();\n";
	}

	/** {@inheritDoc} */
	@Override
	public final String getSingletonIdentifier() {
		// use header file as singleton identifier
		return getHeaderFileName();
	}

	/** {@inheritDoc} */
	@Override
	public final String getHeaderFileName() {
		return "af3_v2v.h";
	}
}
